Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(755)

Unified Diff: chrome/browser/search/local_ntp_source.h

Issue 12840003: Implement local NTP for fallback. (Closed) Base URL: https://git.chromium.org/chromium/src.git@master
Patch Set: Fix compile. Created 7 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/search/instant_service.cc ('k') | chrome/browser/search/local_ntp_source.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/search/local_ntp_source.h
diff --git a/chrome/browser/search/local_omnibox_popup_source.h b/chrome/browser/search/local_ntp_source.h
similarity index 53%
copy from chrome/browser/search/local_omnibox_popup_source.h
copy to chrome/browser/search/local_ntp_source.h
index d477a725c363d5138d6d6f1a1772eda30113696f..8e1a2eb57bbb3ab27e637a87241bf3b58b4b596a 100644
--- a/chrome/browser/search/local_omnibox_popup_source.h
+++ b/chrome/browser/search/local_ntp_source.h
@@ -2,20 +2,23 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_SEARCH_LOCAL_OMNIBOX_POPUP_SOURCE_H_
-#define CHROME_BROWSER_SEARCH_LOCAL_OMNIBOX_POPUP_SOURCE_H_
+#ifndef CHROME_BROWSER_SEARCH_LOCAL_NTP_SOURCE_H_
+#define CHROME_BROWSER_SEARCH_LOCAL_NTP_SOURCE_H_
#include "base/basictypes.h"
#include "base/compiler_specific.h"
#include "content/public/browser/url_data_source.h"
-// Serves HTML and resources for the local omnibox popup i.e.
-// chrome-search://local-omnibox-popup/local_omnibox_popup.html
-class LocalOmniboxPopupSource : public content::URLDataSource {
+// Serves HTML and resources for the local new tab page i.e.
+// chrome-search://local-ntp/local-ntp.html
+class LocalNtpSource : public content::URLDataSource {
public:
- LocalOmniboxPopupSource();
+ LocalNtpSource();
- // content::URLDataSource overrides.
+ private:
+ virtual ~LocalNtpSource();
+
+ // Overridden from content::URLDataSource:
virtual std::string GetSource() OVERRIDE;
virtual void StartDataRequest(
const std::string& path,
@@ -24,12 +27,8 @@ class LocalOmniboxPopupSource : public content::URLDataSource {
virtual std::string GetMimeType(const std::string& path) const OVERRIDE;
virtual bool ShouldServiceRequest(
const net::URLRequest* request) const OVERRIDE;
- virtual std::string GetContentSecurityPolicyFrameSrc() const OVERRIDE;
-
- private:
- virtual ~LocalOmniboxPopupSource();
- DISALLOW_COPY_AND_ASSIGN(LocalOmniboxPopupSource);
+ DISALLOW_COPY_AND_ASSIGN(LocalNtpSource);
};
-#endif // CHROME_BROWSER_SEARCH_LOCAL_OMNIBOX_POPUP_SOURCE_H_
+#endif // CHROME_BROWSER_SEARCH_LOCAL_NTP_SOURCE_H_
« no previous file with comments | « chrome/browser/search/instant_service.cc ('k') | chrome/browser/search/local_ntp_source.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698